<?php

/**
 * This file is part of the Nette Framework (http://nette.org)
 *
 * Copyright (c) 2004, 2011 David Grudl (http://davidgrudl.com)
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package Nette\Loaders
 */



/**
 * Nette auto loader is responsible for loading Nette classes and interfaces.
 *
 * @author     David Grudl
 */
class NetteLoader extends AutoLoader
{
	/** @var NetteLoader */
	private static $instance;

	/** @var array */
	public $list = array(
		'abortexception' => '/Application/exceptions.php',
		'ambiguousserviceexception' => '/DI/AmbiguousServiceException.php',
		'annotation' => '/Reflection/Annotation.php',
		'annotationsparser' => '/Reflection/AnnotationsParser.php',
		'appform' => '/Application/UI/Form.php',
		'application' => '/Application/Application.php',
		'applicationexception' => '/Application/exceptions.php',
		'argumentoutofrangeexception' => '/common/exceptions.php',
		'arrayhash' => '/common/ArrayHash.php',
		'arraylist' => '/common/ArrayList.php',
		'arraytools' => '/common/ArrayUtils.php',
		'authenticationexception' => '/Security/AuthenticationException.php',
		'autoloader' => '/Loaders/AutoLoader.php',
		'badrequestexception' => '/Application/exceptions.php',
		'badsignalexception' => '/Application/UI/BadSignalException.php',
		'button' => '/Forms/Controls/Button.php',
		'cache' => '/Caching/Cache.php',
		'cachinghelper' => '/Caching/OutputHelper.php',
		'callback' => '/common/Callback.php',
		'callbackfilteriterator' => '/Iterators/Filter.php',
		'checkbox' => '/Forms/Controls/Checkbox.php',
		'classreflection' => '/Reflection/ClassType.php',
		'clirouter' => '/Application/Routers/CliRouter.php',
		'component' => '/ComponentModel/Component.php',
		'componentcontainer' => '/ComponentModel/Container.php',
		'config' => '/Config/Config.php',
		'configadapterini' => '/Config/IniAdapter.php',
		'configadapterneon' => '/Config/NeonAdapter.php',
		'configurator' => '/DI/Configurator.php',
		'connection' => '/Database/Connection.php',
		'context' => '/DI/Context.php',
		'control' => '/Application/UI/Control.php',
		'criticalsection' => '/Utils/CriticalSection.php',
		'databasepanel' => '/Database/Diagnostics/ConnectionPanel.php',
		'databasereflection' => '/Database/Reflection/DatabaseReflection.php',
		'datetime53' => '/common/DateTime.php',
		'debug' => '/Diagnostics/Debugger.php',
		'debughelpers' => '/Diagnostics/Helpers.php',
		'debugpanel' => '/Diagnostics/Panel.php',
		'defaultformrenderer' => '/Forms/Rendering/DefaultFormRenderer.php',
		'deprecatedexception' => '/common/exceptions.php',
		'directorynotfoundexception' => '/common/exceptions.php',
		'downloadresponse' => '/Application/Responses/FileResponse.php',
		'dummystorage' => '/Caching/Storages/DevNullStorage.php',
		'environment' => '/common/Environment.php',
		'extensionreflection' => '/Reflection/Extension.php',
		'fatalerrorexception' => '/common/exceptions.php',
		'filejournal' => '/Caching/Storages/FileJournal.php',
		'filenotfoundexception' => '/common/exceptions.php',
		'filestorage' => '/Caching/Storages/FileStorage.php',
		'filetemplate' => '/Templating/FileTemplate.php',
		'fileupload' => '/Forms/Controls/UploadControl.php',
		'finder' => '/Utils/Finder.php',
		'forbiddenrequestexception' => '/Application/exceptions.php',
		'form' => '/Forms/Form.php',
		'formcontainer' => '/Forms/Container.php',
		'formcontrol' => '/Forms/Controls/BaseControl.php',
		'formgroup' => '/Forms/ControlGroup.php',
		'forwardingresponse' => '/Application/Responses/ForwardResponse.php',
		'framework' => '/common/Framework.php',
		'freezableobject' => '/common/FreezableObject.php',
		'functionreflection' => '/Reflection/GlobalFunction.php',
		'genericrecursiveiterator' => '/Iterators/Recursor.php',
		'groupedtableselection' => '/Database/Table/GroupedSelection.php',
		'hiddenfield' => '/Forms/Controls/HiddenField.php',
		'html' => '/Utils/Html.php',
		'httpcontext' => '/Http/Context.php',
		'httprequest' => '/Http/Request.php',
		'httprequestfactory' => '/Http/RequestFactory.php',
		'httpresponse' => '/Http/Response.php',
		'httpuploadedfile' => '/Http/FileUpload.php',
		'iannotation' => '/Reflection/IAnnotation.php',
		'iauthenticator' => '/Security/IAuthenticator.php',
		'iauthorizator' => '/Security/IAuthorizator.php',
		'icachejournal' => '/Caching/Storages/IJournal.php',
		'icachestorage' => '/Caching/IStorage.php',
		'icomponent' => '/ComponentModel/IComponent.php',
		'icomponentcontainer' => '/ComponentModel/IContainer.php',
		'iconfigadapter' => '/Config/IAdapter.php',
		'icontext' => '/DI/IContext.php',
		'idebugpanel' => '/Diagnostics/IPanel.php',
		'identity' => '/Security/Identity.php',
		'ifiletemplate' => '/Templating/IFileTemplate.php',
		'iformcontrol' => '/Forms/IControl.php',
		'iformrenderer' => '/Forms/IFormRenderer.php',
		'ifreezable' => '/common/IFreezable.php',
		'ihttprequest' => '/Http/IRequest.php',
		'ihttpresponse' => '/Http/IResponse.php',
		'iidentity' => '/Security/IIdentity.php',
		'image' => '/common/Image.php',
		'imagebutton' => '/Forms/Controls/ImageButton.php',
		'imailer' => '/Mail/IMailer.php',
		'instancefilteriterator' => '/Iterators/InstanceFilter.php',
		'invalidlinkexception' => '/Application/UI/InvalidLinkException.php',
		'invalidpresenterexception' => '/Application/exceptions.php',
		'invalidstateexception' => '/common/exceptions.php',
		'ioexception' => '/common/exceptions.php',
		'ipartiallyrenderable' => '/Application/UI/IPartiallyRenderable.php',
		'ipresenter' => '/Application/IPresenter.php',
		'ipresenterfactory' => '/Application/IPresenterFactory.php',
		'ipresenterresponse' => '/Application/IResponse.php',
		'irenderable' => '/Application/UI/IRenderable.php',
		'iresource' => '/Security/IResource.php',
		'irole' => '/Security/IRole.php',
		'irouter' => '/Application/IRouter.php',
		'isessionstorage' => '/Http/ISessionStorage.php',
		'isignalreceiver' => '/Application/UI/ISignalReceiver.php',
		'istatepersistent' => '/Application/UI/IStatePersistent.php',
		'isubmittercontrol' => '/Forms/ISubmitterControl.php',
		'isupplementaldriver' => '/Database/ISupplementalDriver.php',
		'itemplate' => '/Templating/ITemplate.php',
		'itranslator' => '/Localization/ITranslator.php',
		'iuser' => '/Http/IUser.php',
		'json' => '/Utils/Json.php',
		'jsonexception' => '/Utils/Json.php',
		'jsonresponse' => '/Application/Responses/JsonResponse.php',
		'latteexception' => '/Latte/ParseException.php',
		'lattefilter' => '/Latte/Engine.php',
		'lattemacros' => '/Latte/DefaultMacros.php',
		'limitedscope' => '/Utils/LimitedScope.php',
		'link' => '/Application/UI/Link.php',
		'mail' => '/Mail/Message.php',
		'mailmimepart' => '/Mail/MimePart.php',
		'mapiterator' => '/Iterators/Mapper.php',
		'memberaccessexception' => '/common/exceptions.php',
		'memcachedstorage' => '/Caching/Storages/MemcachedStorage.php',
		'memorystorage' => '/Caching/Storages/MemoryStorage.php',
		'methodreflection' => '/Reflection/Method.php',
		'mimetypedetector' => '/Utils/MimeTypeDetector.php',
		'multirouter' => '/Application/Routers/RouteList.php',
		'multiselectbox' => '/Forms/Controls/MultiSelectBox.php',
		'nclosurefix' => '/common/Framework.php',
		'neon' => '/Utils/Neon.php',
		'neonexception' => '/Utils/Neon.php',
		'netteloader' => '/Loaders/NetteLoader.php',
		'notimplementedexception' => '/common/exceptions.php',
		'notsupportedexception' => '/common/exceptions.php',
		'object' => '/common/Object.php',
		'objectmixin' => '/common/ObjectMixin.php',
		'paginator' => '/Utils/Paginator.php',
		'parameterreflection' => '/Reflection/Parameter.php',
		'pdomssqldriver' => '/Database/Drivers/MsSqlDriver.php',
		'pdomysqldriver' => '/Database/Drivers/MySqlDriver.php',
		'pdoocidriver' => '/Database/Drivers/OciDriver.php',
		'pdoodbcdriver' => '/Database/Drivers/OdbcDriver.php',
		'pdopgsqldriver' => '/Database/Drivers/PgSqlDriver.php',
		'pdosqlite2driver' => '/Database/Drivers/Sqlite2Driver.php',
		'pdosqlitedriver' => '/Database/Drivers/SqliteDriver.php',
		'permission' => '/Security/Permission.php',
		'presenter' => '/Application/UI/Presenter.php',
		'presentercomponent' => '/Application/UI/PresenterComponent.php',
		'presentercomponentreflection' => '/Application/UI/PresenterComponentReflection.php',
		'presenterfactory' => '/Application/PresenterFactory.php',
		'presenterrequest' => '/Application/Request.php',
		'propertyreflection' => '/Reflection/Property.php',
		'radiolist' => '/Forms/Controls/RadioList.php',
		'recursivecallbackfilteriterator' => '/Iterators/RecursiveFilter.php',
		'recursivecomponentiterator' => '/ComponentModel/RecursiveComponentIterator.php',
		'redirectingresponse' => '/Application/Responses/RedirectResponse.php',
		'regexpexception' => '/common/StringUtils.php',
		'renderresponse' => '/Application/Responses/TextResponse.php',
		'robotloader' => '/Loaders/RobotLoader.php',
		'route' => '/Application/Routers/Route.php',
		'routingdebugger' => '/Application/Diagnostics/RoutingPanel.php',
		'row' => '/Database/Row.php',
		'rule' => '/Forms/Rule.php',
		'rules' => '/Forms/Rules.php',
		'safestream' => '/Utils/SafeStream.php',
		'selectbox' => '/Forms/Controls/SelectBox.php',
		'sendmailmailer' => '/Mail/SendmailMailer.php',
		'session' => '/Http/Session.php',
		'sessionnamespace' => '/Http/SessionNamespace.php',
		'simpleauthenticator' => '/Security/SimpleAuthenticator.php',
		'simplerouter' => '/Application/Routers/SimpleRouter.php',
		'smartcachingiterator' => '/Iterators/CachingIterator.php',
		'smtpexception' => '/Mail/SmtpMailer.php',
		'smtpmailer' => '/Mail/SmtpMailer.php',
		'sqlliteral' => '/Database/SqlLiteral.php',
		'sqlpreprocessor' => '/Database/SqlPreprocessor.php',
		'statement' => '/Database/Statement.php',
		'string' => '/common/StringUtils.php',
		'submitbutton' => '/Forms/Controls/SubmitButton.php',
		'tablerow' => '/Database/Table/ActiveRow.php',
		'tableselection' => '/Database/Table/Selection.php',
		'template' => '/Templating/Template.php',
		'templatecachestorage' => '/Templating/PhpFileStorage.php',
		'templateexception' => '/Templating/FilterException.php',
		'templatehelpers' => '/Templating/DefaultHelpers.php',
		'textarea' => '/Forms/Controls/TextArea.php',
		'textbase' => '/Forms/Controls/TextBase.php',
		'textinput' => '/Forms/Controls/TextInput.php',
		'tokenizer' => '/Utils/Tokenizer.php',
		'tokenizerexception' => '/Utils/Tokenizer.php',
		'uri' => '/Http/Url.php',
		'uriscript' => '/Http/UrlScript.php',
		'user' => '/Http/User.php',
	);



	/**
	 * Returns singleton instance with lazy instantiation.
	 * @return NetteLoader
	 */
	public static function getInstance()
	{
		if (self::$instance === NULL) {
			self::$instance = new self;
		}
		return self::$instance;
	}



	/**
	 * Handles autoloading of classes or interfaces.
	 * @param  string
	 * @return void
	 */
	public function tryLoad($type)
	{
		$type = ltrim(strtolower($type), '\\');
		if (isset($this->list[$type])) {
			LimitedScope::load(NETTE_DIR . $this->list[$type]);
			self::$count++;
		}
	}

}
