<?php

/**
 * Test: ConfigAdapterNeon section.
 *
 * @author     David Grudl
 * @package    Nette\Config
 * @subpackage UnitTests
 */



require dirname(__FILE__) . '/../bootstrap.php';

define('TEMP_FILE', dirname(__FILE__) . '/tmp/cfg.neon');


// Load INI
$config = Config::fromFile('config2.neon');
Assert::same( array(
	'common' => array(
		'variable' => array(
			'tempDir' => '%appDir%/cache',
			'foo' => '%bar% world',
			'bar' => 'hello',
		),
		'set' => array(
			'date.timezone' => 'Europe/Prague',
			'iconv.internal_encoding' => '%encoding%',
			'mbstring.internal_encoding' => '%encoding%',
			'include_path' => '%appDir%/../_trunk;%appDir%/libs',
		),
	),
	'production' => array(
		'service' => array(
			'IRouter' => 'Nette\\Application\\MultiRouter',
			'User' => 'Nette\\Security\\User',
			'Autoloader' => 'Nette\\AutoLoader',
		),
		'webhost' => 'www.example.com',
		'database' => array(
			'params' => array(
				'host' => 'db.example.com',
				'username' => 'dbuser',
				'password' => 'secret',
				'dbname' => 'dbname',
			),
			'adapter' => 'pdo_mysql',
		),
		'variable' => array(
			'tempDir' => '%appDir%/cache',
			'foo' => '%bar% world',
			'bar' => 'hello',
		),
		'set' => array(
			'date.timezone' => 'Europe/Prague',
			'iconv.internal_encoding' => '%encoding%',
			'mbstring.internal_encoding' => '%encoding%',
			'include_path' => '%appDir%/../_trunk;%appDir%/libs',
		),
	),
	'development' => array(
		'database' => array(
			'params' => array(
				'host' => 'dev.example.com',
				'username' => 'devuser',
				'password' => 'devsecret',
				'dbname' => 'dbname',
			),
			'adapter' => 'pdo_mysql',
		),
		'service' => array(
			'IRouter' => 'Nette\\Application\\MultiRouter',
			'User' => 'Nette\\Security\\User',
			'Autoloader' => 'Nette\\AutoLoader',
		),
		'webhost' => 'www.example.com',
		'variable' => array(
			'tempDir' => '%appDir%/cache',
			'foo' => '%bar% world',
			'bar' => 'hello',
		),
		'set' => array(
			'date.timezone' => 'Europe/Prague',
			'iconv.internal_encoding' => '%encoding%',
			'mbstring.internal_encoding' => '%encoding%',
			'include_path' => '%appDir%/../_trunk;%appDir%/libs',
		),
		'test' => array(
			'host' => 'localhost',
			'params' => array(
				'host' => 'dev.example.com',
				'username' => 'devuser',
				'password' => 'devsecret',
				'dbname' => 'dbname',
			),
			'adapter' => 'pdo_mysql',
		),
	),
	'extra' => array(
		'set' => array(
			'date.timezone' => 'Europe/Paris',
			'iconv.internal_encoding' => '%encoding%',
			'mbstring.internal_encoding' => '%encoding%',
			'include_path' => '%appDir%/../_trunk;%appDir%/libs',
		),
	),
), $config->toArray() );



// Save
$config->save(TEMP_FILE);
Assert::match( <<<EOD
# generated by Nette

common:
	variable:
		tempDir: %appDir%/cache
		foo: %bar% world
		bar: hello

	set:
		date.timezone: Europe/Prague
		iconv.internal_encoding: %encoding%
		mbstring.internal_encoding: %encoding%
		include_path: %appDir%/../_trunk;%appDir%/libs


production:
	service:
		IRouter: Nette\Application\MultiRouter
		User: Nette\Security\User
		Autoloader: Nette\AutoLoader

	webhost: www.example.com
	database:
		params:
			host: db.example.com
			username: dbuser
			password: secret
			dbname: dbname

		adapter: pdo_mysql

	variable:
		tempDir: %appDir%/cache
		foo: %bar% world
		bar: hello

	set:
		date.timezone: Europe/Prague
		iconv.internal_encoding: %encoding%
		mbstring.internal_encoding: %encoding%
		include_path: %appDir%/../_trunk;%appDir%/libs


development:
	database:
		params:
			host: dev.example.com
			username: devuser
			password: devsecret
			dbname: dbname

		adapter: pdo_mysql

	service:
		IRouter: Nette\Application\MultiRouter
		User: Nette\Security\User
		Autoloader: Nette\AutoLoader

	webhost: www.example.com
	variable:
		tempDir: %appDir%/cache
		foo: %bar% world
		bar: hello

	set:
		date.timezone: Europe/Prague
		iconv.internal_encoding: %encoding%
		mbstring.internal_encoding: %encoding%
		include_path: %appDir%/../_trunk;%appDir%/libs

	test:
		host: localhost
		params:
			host: dev.example.com
			username: devuser
			password: devsecret
			dbname: dbname

		adapter: pdo_mysql


extra:
	set:
		date.timezone: Europe/Paris
		iconv.internal_encoding: %encoding%
		mbstring.internal_encoding: %encoding%
		include_path: %appDir%/../_trunk;%appDir%/libs
EOD
, file_get_contents(TEMP_FILE) );



$config = Config::fromFile('config2.neon', 'development');
Assert::same( array(
	'database' => array(
		'params' => array(
			'host' => 'dev.example.com',
			'username' => 'devuser',
			'password' => 'devsecret',
			'dbname' => 'dbname',
		),
		'adapter' => 'pdo_mysql',
	),
	'service' => array(
		'IRouter' => 'MultiRouter',
		'User' => 'User',
		'Autoloader' => 'AutoLoader',
	),
	'webhost' => 'www.example.com',
	'variable' => array(
		'tempDir' => '%appDir%/cache',
		'foo' => '%bar% world',
		'bar' => 'hello',
	),
	'set' => array(
		'date.timezone' => 'Europe/Prague',
		'iconv.internal_encoding' => '%encoding%',
		'mbstring.internal_encoding' => '%encoding%',
		'include_path' => '%appDir%/../_trunk;%appDir%/libs',
	),
	'test' => array(
		'host' => 'localhost',
		'params' => array(
			'host' => 'dev.example.com',
			'username' => 'devuser',
			'password' => 'devsecret',
			'dbname' => 'dbname',
		),
		'adapter' => 'pdo_mysql',
	),
), $config->toArray() );

$config->display_errors = true;
$config->html_errors = false;
$config->save(TEMP_FILE);
Assert::match( <<<EOD
# generated by Nette

database:
	params:
		host: dev.example.com
		username: devuser
		password: devsecret
		dbname: dbname

	adapter: pdo_mysql

service:
	IRouter: Nette\Application\MultiRouter
	User: Nette\Security\User
	Autoloader: Nette\AutoLoader

webhost: www.example.com
variable:
	tempDir: %appDir%/cache
	foo: %bar% world
	bar: hello

set:
	date.timezone: Europe/Prague
	iconv.internal_encoding: %encoding%
	mbstring.internal_encoding: %encoding%
	include_path: %appDir%/../_trunk;%appDir%/libs

test:
	host: localhost
	params:
		host: dev.example.com
		username: devuser
		password: devsecret
		dbname: dbname

	adapter: pdo_mysql

display_errors: true
html_errors: false
EOD
, file_get_contents(TEMP_FILE) );
